Snippet update
===============

.. automodule:: drain_swamp.snippet_sphinx_conf
   :members:
   :undoc-members:
   :exclude-members: DOC_FOLDERS
   :platform: Unix
   :synopsis: update Sphinx conf snippet
